@@ -25,13 +25,13 @@ void ConnectedApplicationsTable::setModel(QAbstractItemModel *model)
 {
     Q_ASSERT(_wallet != nullptr);
 
-    ConnectedAppModel *appModel = qobject_cast<ConnectedAppModel *>(model);
+    auto appModel = qobject_cast<ConnectedAppModel *>(model);
     Q_ASSERT(appModel != nullptr);
 
     QTableView::setModel(model);
     const int numberRow(model->rowCount());
     for (int row = 0; row < numberRow; row++) {
-        DisconnectAppButton *btn = new DisconnectAppButton(model->index(row, 0).data().toString(), _wallet);
+        auto btn = new DisconnectAppButton(model->index(row, 0).data().toString(), _wallet);
         btn->setFixedHeight(btn->sizeHint().height());
         setRowHeight(row, btn->height());
         setIndexWidget(model->index(row, 1), btn);
